
/* Chrysalide - Outil d'analyse de fichiers binaires
 * gtkextstatusbar.h - prototypes pour la barre de statut améliorée
 *
 * Copyright (C) 2009-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef _GTKEXT_GTKEXTSTATUSBAR_H
#define _GTKEXT_GTKEXTSTATUSBAR_H


#include <stdbool.h>
#include <gtk/gtk.h>



/* ------------------------- GESTION EXTERIEURE DE LA BARRE ------------------------- */


#define GTK_TYPE_EXT_STATUS_BAR            (gtk_extended_status_bar_get_type())
#define GTK_EXT_STATUS_BAR(obj)            (G_TYPE_CHECK_INSTANCE_CAST(obj, gtk_extended_status_bar_get_type (), GtkExtStatusBar))
#define GTK_IS_EXT_STATUS_BAR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE(obj, gtk_extended_status_bar_get_type()))
#define GTK_EXT_STATUS_BAR_CLASS(klass)    (G_LOADED_BINARY_GET_CLASS(klass, gtk_extended_status_bar_get_type(), GtkExtStatusBarClass))


/* Abstration d'une gestion de barre de statut (instance) */
typedef struct _GtkExtStatusBar GtkExtStatusBar;

/* Abstration d'une gestion de barre de statut (classe) */
typedef struct _GtkExtStatusBarClass GtkExtStatusBarClass;


/* Identifiant d'un message de statut */
typedef size_t * bstatus_id_t;


/* Détermine le type de la barre de statut améliorée. */
GType gtk_extended_status_bar_get_type(void);

/* Crée une nouvelle instance de barre de statut. */
GtkWidget *gtk_extended_status_bar_new(void);

/* Place un nouveau message dans la barre de statut. */
bstatus_id_t gtk_extended_status_bar_push(GtkExtStatusBar *, const gchar *, bool);

/* Met à jour la barre de progression de la barre de statut. */
void gtk_extended_status_bar_update_activity(GtkExtStatusBar *, bstatus_id_t, double);

/* Retire de la barre un statut, visible ou non. */
void gtk_extended_status_bar_remove(GtkExtStatusBar *, bstatus_id_t);



/* -------------------------- GESTION EN VUE MACROSCOPIQUE -------------------------- */


/* Concentré d'informations utiles */
typedef struct _status_blob_info status_blob_info;


/* Met en place rapidement un message progressiste de statut. */
status_blob_info *init_progessive_status(GtkExtStatusBar *, const char *, double, double);

/* Fait disparaître la glue d'affichage de progression. */
void fini_progessive_status(status_blob_info *);

/* Indique la valeur courante utilisée pour la progression. */
double get_current_progessive_status(const status_blob_info *);

/* Augmente la progression visible dans la barre de statut. */
void inc_progessive_status(status_blob_info *, double);



#endif  /* _GTKEXT_GTKEXTSTATUSBAR_H */
